==> sponge-features-1.15.0-sources.jar: org/openksavi/sponge/features/model/geo/GeoPosition.java <==
/*
 * Copyright 2016-2020 The Sponge authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.openksavi.sponge.features.model.geo;

import java.io.Serializable;

/**
 * A geo position.
 */
public class GeoPosition implements Serializable {

    private static final long serialVersionUID = -711901067929339815L;

    private Double latitude;

    private Double longitude;

    public GeoPosition(Double latitude, Double longitude) {
        this.latitude = latitude;
        this.longitude = longitude;
    }

    public GeoPosition() {
    }

    public GeoPosition withLatitude(Double latitude) {
        setLatitude(latitude);
        return this;
    }

    public GeoPosition withLongitude(Double longitude) {
        setLongitude(longitude);
        return this;
    }

    public Double getLatitude() {
        return latitude;
    }

    public void setLatitude(Double latitude) {
        this.latitude = latitude;
    }

    public Double getLongitude() {
        return longitude;
    }

    public void setLongitude(Double longitude) {
        this.longitude = longitude;
    }
}

==> sponge-features-1.17.1-sources.jar: org/openksavi/sponge/features/model/geo/GeoPosition.java <==
/*
 * Copyright 2016-2020 The Sponge authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.openksavi.sponge.features.model.geo;

import java.io.Serializable;

import org.openksavi.sponge.SpongeException;

/**
 * A geo position.
 */
public class GeoPosition implements Serializable, Cloneable {

    private static final long serialVersionUID = -711901067929339815L;

    private Double latitude;

    private Double longitude;

    public GeoPosition(Double latitude, Double longitude) {
        this.latitude = latitude;
        this.longitude = longitude;
    }

    public GeoPosition() {
    }

    public GeoPosition withLatitude(Double latitude) {
        setLatitude(latitude);
        return this;
    }

    public GeoPosition withLongitude(Double longitude) {
        setLongitude(longitude);
        return this;
    }

    public Double getLatitude() {
        return latitude;
    }

    public void setLatitude(Double latitude) {
        this.latitude = latitude;
    }

    public Double getLongitude() {
        return longitude;
    }

    public void setLongitude(Double longitude) {
        this.longitude = longitude;
    }

    @Override
    public GeoPosition clone() {
        try {
            return (GeoPosition) super.clone();
        } catch (CloneNotSupportedException e) {
            throw new SpongeException(e);
        }
    }
}
